@@ -98,7 +98,8 @@ COLOR_CODES = {'b': 'blue', 'g': 'green', 'r': 'red', 'c': 'cyan',
                'm': 'magenta', 'y': 'yellow', 'k': 'black'}
 
 MARKER_CODES = {'o': 'circle', 'v': 'triangle-down', '^': 'triangle-up',
-                's': 'square', 'd': 'diamond', '+': 'cross'}
+                's': 'square', 'd': 'diamond', '+': 'cross', 'p': 'plus',
+                'x': 'crosshair', '.': 'point'}
 
 
 PY2 = sys.version_info[0] == 2
@@ -210,7 +211,7 @@ def figure(key=None, fig=None, **kwargs):
     # from the possible dimensions in the figure to the list of scales with
     # respect to which axes have been drawn for this figure.
     # Used to automatically generate axis.
-    if(getattr(_context['figure'], 'axis_registry', None) is None):
+    if getattr(_context['figure'], 'axis_registry', None) is None:
         setattr(_context['figure'], 'axis_registry', {})
     return _context['figure']
 
@@ -397,7 +398,7 @@ def axes(mark=None, options={}, **kwargs):
         # An axis must be created. We fetch the type from the registry
         # the key being provided in the scaled attribute decoration
         key = mark.class_traits()[name].get_metadata('atype')
-        if(key is not None):
+        if key is not None:
             axis_type = Axis.axis_types[key]
             axis = axis_type(scale=scales[name], **axis_args)
             axes[name] = axis
@@ -1340,7 +1341,7 @@ def _get_attribute_dimension(trait_name, mark_type=None):
     as is.
     Returns `None` if the `trait_name` is not valid for `mark_type`.
     """
-    if(mark_type is None):
+    if mark_type is None:
         return trait_name
     scale_metadata = mark_type.class_traits()['scales_metadata']\
         .default_args[0]
